@@ -11,7 +11,7 @@ import logging, sys
 
 
 __all__ = ('BaseCmd',)
-__version__ = '0.1.1'
+__version__ = '0.1.2'
 
 
 class BaseCmd:
@@ -49,10 +49,10 @@ class BaseCmd:
                 record.levelno, self.default_formatter).format(record)
 
 
-    def __init__(self):
+    def __init__(self, **kw):
         self.parse_args()
         self.init_logging()
-        super(BaseCmd, self).__init__()
+        super(BaseCmd, self).__init__(**kw)
     
     
     def init_logging(self):
